@@ -7,9 +7,9 @@ use warnings;
 use Exporter qw(import);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-05-22'; # DATE
+our $DATE = '2022-06-02'; # DATE
 our $DIST = 'Array-Shuffle'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our @EXPORT_OK = qw(shuffle);
 
@@ -46,10 +46,26 @@ Array::Shuffle - Shuffle an array
 
 =head1 VERSION
 
-This document describes version 0.002 of Array::Shuffle (from Perl distribution Array-Shuffle), released on 2022-05-22.
+This document describes version 0.003 of Array::Shuffle (from Perl distribution Array-Shuffle), released on 2022-06-02.
 
 =head1 SYNOPSIS
 
+ use Array::Shuffle qw(shuffle);
+
+ my @myarray = (1..10);
+ my @shuffled = shuffle(\@myarray);
+
+ # shuffle inplace
+ shuffle(\@myarray, {inplace=>1});
+
+=head1 DESCRIPTION
+
+This module provides C<shuffle()> to shuffle an array using the standard
+Fisher-Yates algorithm, like that implemented in L<List::Util> or
+L<List::MoreUtils>. It accepts an arrayref instead of a list and can be
+instructed to shuffle the array in-place. There will be more options provided in
+the future.
+
 =head1 FUNCTIONS
 
 =head2 shuffle
