@@ -7,9 +7,9 @@ use warnings;
 use Exporter qw(import);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-05-22'; # DATE
+our $DATE = '2022-06-02'; # DATE
 our $DIST = 'Array-Shuffle'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our @EXPORT_OK = qw(shuffle);
 
@@ -37,7 +37,7 @@ Array::Shuffle::Weighted - Shuffle an array, with weighting options
 
 =head1 VERSION
 
-This document describes version 0.002 of Array::Shuffle::Weighted (from Perl distribution Array-Shuffle), released on 2022-05-22.
+This document describes version 0.003 of Array::Shuffle::Weighted (from Perl distribution Array-Shuffle), released on 2022-06-02.
 
 =head1 SYNOPSIS
 
@@ -51,7 +51,7 @@ Usage:
 
  shuffle(\@ary [ , \%opts ]
 
-Given array reference (C<\@ary>), shuffle it. Each array elment must be a
+Given array reference (C<\@ary>), shuffle it. Each array element must be a
 2-element arrayref C<< [$val, $weight] >>. The greater the weight, the greater
 the chance that the value will be shuffled into the beginning of the array.
 
